# LOAD DATA:

library(foreign)
library(Matching)
rm(list=ls(all=TRUE))

In.Peace <- read.dta('C:/Peace/peace_pre_match.dta')
attach(In.Peace)


# SET GENMATCH INPUTS:

X <- cbind(lwdeaths, lwdurat, milper, pop, ethfrac, lmtnest, bwplty2,
 ssafrica, asia, lamerica)

BalanceMat <- cbind(lwdeaths, lwdurat, milper, pop, ethfrac, lmtnest, bwplty2,
 ssafrica, asia, lamerica)


# BALANCE:

genout <- GenMatch(Tr=UN, X=X, BalanceMatrix=BalanceMat, estimand="ATT",
 M=1, pop.size=1000, max.generations=100, wait.generations=10,
 int.seed=7, unif.seed=10, data.type.int=FALSE)


# MATCH:

mout <- Match(Y=ldur, Tr=UN, X=X, estimand="ATT", Weight.matrix=genout, M=1)
summary(mout)

mout$index.treated
mout$index.control

p.match <- rbind(In.Peace[mout$index.treated,], In.Peace[mout$index.control,])
write.dta(p.match,'C:/Peace/peace_post_match.dta')


# CHECK BALANCE:

mb <- MatchBalance ( UN ~ lwdeaths + lwdurat + ethfrac + pop +
	lmtnest + milper + bwgdp + bwplty2 +
	eeurop + lamerica + asia + nafrme + ssafrica,
	match.out=mout, nboots=500, ks=TRUE, mv=FALSE )


# CREATE Q-Q PLOTS

poo1 <- In.Peace[mout$index.treated,]

names(poo1)[names(poo1) == "lwdeaths"] <- "lwdeaths_t"
names(poo1)[names(poo1) == "lwdurat"] <- "lwdurat_t"
names(poo1)[names(poo1) == "ethfrac"] <- "ethfrac_t"
names(poo1)[names(poo1) == "pop"] <- "pop_t"
names(poo1)[names(poo1) == "lmtnest"] <- "lmtnest_t"
names(poo1)[names(poo1) == "milper"] <- "milper_t"
names(poo1)[names(poo1) == "bwgdp"] <- "bwgdp_t"
names(poo1)[names(poo1) == "bwplty2"] <- "bwplty2_t"

poo <- cbind(poo1, In.Peace[mout$index.control, ])
detach(In.Peace)
attach(poo)

postscript("C:/Peace/peace_qqplots.ps",width=6.25,height=7.75,
horizontal=FALSE)
par(mfrow=c(3,3))

qqplot(lwdeaths, lwdeaths_t, xlab = "Control",
 ylab = "Treated",ylim=c(0,12),xlim=c(0,12),type="l",lwd=2)
abline(0,1)
title(main="Log Cumulative Battle Deaths")

qqplot(lwdurat, lwdurat_t, xlab = "Control", ylab = "Treated",
 xlim=c(0,200), ylim=c(0,200),type="l",lwd=2)
abline(0,1)
title(main="Duration of Last War")

qqplot(ethfrac, ethfrac_t, xlab = "Control", ylab = "Treated",
 type="l",lwd=2)
abline(0,1)
title(main="Ethnic Fractionalizaion")

qqplot(pop, pop_t, xlab = "Control", ylab = "Treated",
 type="l",lwd=2, xlim=c(7,11), ylim=c(7,11))
abline(0,1)
title(main="Log Population Size")

qqplot(lmtnest, lmtnest_t, xlab = "Control", ylab = "Treated",
 type="l",lwd=2)
abline(0,1)
title(main="Log Mountainous")

qqplot(milper, milper_t, xlab = "Control", ylab = "Treated",
 type="l",lwd=2, xlim=c(1,8), ylim=c(1,8))
abline(0,1)
title(main="Log Military Personnel")

qqplot(bwgdp, bwgdp_t, xlab = "Control", ylab = "Treated",
 type="l",lwd=2, xlim=c(5,10), ylim=c(5,10))
abline(0,1)
title(main="Log GDP per Capita")

qqplot(bwplty2, bwplty2_t, xlab = "Control", ylab = "Treated",
 type="l",lwd=2, xlim=c(-10,10), ylim=c(-10,10))
abline(0,1)
title(main="Polity")

dev.off()
