# delimit;
clear;
set mem 128m;
set more off;


* ******************************************************************	*;
*  CREATE TREATMENTS & BASE CONTROLS;
* ******************************************************************	*;

use "C:\Peace\war_pre_match.dta", clear;

replace id = id + string(UN);

sort id _t0;

gen pop_ts = pop;
by id: replace pop = pop[_n-1] + pop_ts if _n > 1;

gen milper_ts = milper;
by id: replace milper = milper[_n-1] + milper_ts if _n > 1 & milper[_n-1] != .;

gen deaths_ts = deaths; 
by id: replace deaths = deaths[_n-1] + deaths_ts if _n > 1;

gen inter_ts = inter; 
by id: replace inter = inter[_n-1] + inter_ts if _n > 1;

collapse (mean) ethfrac lmtnest eeurop lamerica ssafrica nafrme asia
 (min) pop milper deaths inter _t0 date0
 (max) _st _t _d date1 couprev sos drugs UN,
  by(id ccode cname);


gen dur = ( _t - _t0);
gen ldur = ln(dur);

sort id;
drop if substr( id,1,5) == substr( id[_n+1],1,5) ;
drop if substr( id,1,4) == substr( id[_n+1],1,4) & substr(id,3,1) == "_";

drop if date0 > 515;  
rename _t0 t0;
rename _t t;

drop if milper == . | ethfrac == .;

order id cname ccode date0 date1 UN inter deaths couprev sos drugs ethfrac pop lmtnest milper eeurop lamerica asia ssafrica nafrme;
sort ccode id;

mark miss;
markout miss couprev sos drugs;
drop if miss == 0;
drop miss;

save C:\data\war_snap_0.dta, replace;



* ******************************************************************	*;
*  CREATE OTHER CONTRLS;
* ******************************************************************	*;

foreach j in 1 2 3 4 5 6 7 8 9 10 11 12 15 16 18 20 25 30 33 35 36 40 45 50 60 87 95 135 150 154 158

{;
use "C:\Peace\war_pre_match.dta", clear;

replace id = id + "0";

drop if _t0 < `j'; 

sort id _t0;

gen pop_ts = pop;
by id: replace pop = pop[_n-1] + pop_ts if _n > 1;

gen milper_ts = milper;
by id: replace milper = milper[_n-1] + milper_ts if _n > 1 & milper[_n-1] != .;

gen deaths_ts = deaths; 
by id: replace deaths = deaths[_n-1] + deaths_ts if _n > 1;

gen inter_ts = inter; 
by id: replace inter = inter[_n-1] + inter_ts if _n > 1;

collapse (mean) ethfrac lmtnest eeurop lamerica ssafrica nafrme asia
 (min) pop milper deaths inter _t0 date0
 (max) _st _t _d date1 couprev sos drugs UN,
  by(id ccode cname);

drop if UN > 0;


gen dur = ( _t - _t0);
gen ldur = ln(dur);

sort id;
drop if substr( id,1,5) == substr( id[_n+1],1,5) ;
drop if substr( id,1,4) == substr( id[_n+1],1,4) & substr(id,3,1) == "_";

drop if date0 > 515;  
rename _t0 t0;
rename _t t;

drop if milper == . | ethfrac == .;

order id cname ccode date0 date1 UN inter deaths couprev sos drugs ethfrac pop lmtnest milper eeurop lamerica asia ssafrica nafrme;
sort ccode id;

mark miss;
markout miss couprev sos drugs;
drop if miss == 0;
drop miss;

save C:\data\war_snap_`j'.dta, replace;

};


* ******************************************************************	*;
*  APPEND & SAVE;
* ******************************************************************	*;

use C:\data\match_war_0.dta, clear;

foreach j in 1 2 3 4 5 6 7 8 9 10 11 12 15 16 18 20 25 30 33 35 36 40 45 50 60 87 95 135 150 154 158
{;
append using C:\data\war_snap_`j'.dta;
};

save C:\Peace\war_pre_snapshots.dta, replace;


exit;
