# LOAD DATA:

library(foreign)
library(Matching)
rm(list=ls(all=TRUE))

In.War <- read.dta('C:/Peace/war_pre_snapshots.dta')
attach(In.War)


# SET GENMATCH INPUTS:

X <- cbind(t0, lmtnest, drugs, eeurop, pop, lamerica)

BalanceMat <- cbind(t0, lmtnest, drugs, eeurop, pop, lamerica)


# BALANCE:

genout <- GenMatch(Tr=UN, X=X, BalanceMatrix=BalanceMat,estimand="ATT",
 M=1, pop.size=1000, max.generations=100, wait.generations=10,
 int.seed=10, unif.seed=10, data.type.int=FALSE)


# MATCH

mout <- Match(Y=ldur, Tr=UN, X=X, estimand="ATT", Weight.matrix=genout, M=1)
summary(mout)

mout$index.treated
mout$index.control

w.match <- rbind(In.War[mout$index.treated,], In.War[mout$index.control,])
write.dta(w.match,'C:/Peace/war_post_match.dta')


# CHECK BALANCE

mb <- MatchBalance( UN ~ inter + deaths + couprev + sos + drugs +
      t0 + ethfrac + pop + lmtnest + milper +
      eeurop + lamerica + asia + ssafrica + nafrme,
      match.out=mout, nboots=500, ks=TRUE, mv=FALSE)


# CREATE Q-Q PLOTS

foo1 <- In.War[mout$index.treated,]

names(foo1)[names(foo1) == "deaths"] <- "deaths_t"
names(foo1)[names(foo1) == "t0"] <- "t0_t"
names(foo1)[names(foo1) == "ethfrac"] <- "ethfrac_t"
names(foo1)[names(foo1) == "pop"] <- "pop_t"
names(foo1)[names(foo1) == "lmtnest"] <- "lmtnest_t"
names(foo1)[names(foo1) == "milper"] <- "milper_t"


foo = cbind(foo1, In.War[mout$index.control, ])
detach(In.War)
attach(foo)


postscript("C:/Peace/war_qqplots.ps",width=6.25,height=5.25,
horizontal=FALSE)
par(mfrow=c(2,3))

qqplot(deaths, deaths_t, xlab = "Control",
 ylab = "Treated", type="l",lwd=2, xlim=c(4,12), ylim=c(4,12))
abline(0,1)
title(main="Log Battle Deaths")

qqplot(t0, t0_t, xlab = "Control", ylab = "Treated",
 xlim=c(0,150), ylim=c(0,150), type="l",lwd=2)
abline(0,1)
title(main="War Duration")

qqplot(ethfrac, ethfrac_t, xlab = "Control", ylab = "Treated",
 type="l",lwd=2)
abline(0,1)
title(main="Ethnic Fractionalizaion")

qqplot(pop, pop_t, xlab = "Control", ylab = "Treated",
 type="l",lwd=2, xlim=c(8,12), ylim=c(8,12))
abline(0,1)
title(main="Log Population Size")

qqplot(lmtnest, lmtnest_t, xlab = "Control", ylab = "Treated",
 type="l",lwd=2)
abline(0,1)
title(main="Log Mountainous")

qqplot(milper, milper_t, xlab = "Control", ylab = "Treated",
 type="l",lwd=2, xlim=c(0,6), ylim=c(0,6))
abline(0,1)
title(main="Log Military Personnel")

dev.off()

